@@ -17,36 +17,21 @@
  * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
+
+/* qt uses the same trick as us to typedef GLsync on gles2 but to a different
+ * type which confuses the preprocessor.  As it's never actually used by qt
+ * public headers, define it to something else to avoid redefinition
+ * warnings/errors */
+
+#include <gst/gl/gstglconfig.h>
 #include <QtCore/qglobal.h>
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 9, 0))
 #include <QtGui/qtgui-config.h>
 #endif
 
-/* qt uses the same trick as us to typedef GLsync on GLES2 but to a different
- * type which confuses the preprocessor. Instead of trying to reconcile the
- * two, we instead use the GLsync definition from Qt from above, and ensure
- * that we don't typedef GLsync in gstglfuncs.h */
-#include <gst/gl/gstglconfig.h>
-#undef GST_GL_HAVE_GLSYNC
-#define GST_GL_HAVE_GLSYNC 1
-#include <gst/gl/gstglfuncs.h>
-
-/* The glext.h guard was renamed in 2018, but some software which
- * includes their own copy of the GL headers (such as qt) might have
- * older version which use the old guard. This would result in the
- * header being included again (and symbols redefined).
- *
- * To avoid this, we define the "old" guard if the "new" guard is
- * defined.*/
-#if GST_GL_HAVE_OPENGL
-#ifdef __gl_glext_h_
-#ifndef __glext_h_
-#define __glext_h_ 1
-#endif
-#endif
-#endif
-
 #if defined(QT_OPENGL_ES_2)
-#include <QtGui/QOpenGLContext>
-#include <QtGui/QOpenGLFunctions>
+#define GLsync gst_qt_GLsync
+#include <QOpenGLContext>
+#include <QOpenGLFunctions>
+#undef GLsync
 #endif /* defined(QT_OPENGL_ES_2) */
