@@ -673,12 +673,16 @@ send_fragment_opened_closed_msg (GstSplitMuxSink * splitmux, gboolean opened)
 
   g_object_get (splitmux->sink, "location", &location, NULL);
 
-  msg = gst_message_new_element (GST_OBJECT (splitmux),
-      gst_structure_new (msg_name,
-          "location", G_TYPE_STRING, location,
-          "running-time", GST_TYPE_CLOCK_TIME,
-          splitmux->reference_ctx->out_running_time, NULL));
-  gst_element_post_message (GST_ELEMENT_CAST (splitmux), msg);
+  /* If it's in the middle of a teardown, the reference_ctc might have become
+   * NULL */
+  if (splitmux->reference_ctx) {
+    msg = gst_message_new_element (GST_OBJECT (splitmux),
+        gst_structure_new (msg_name,
+            "location", G_TYPE_STRING, location,
+            "running-time", GST_TYPE_CLOCK_TIME,
+            splitmux->reference_ctx->out_running_time, NULL));
+    gst_element_post_message (GST_ELEMENT_CAST (splitmux), msg);
+  }
 
   g_free (location);
 }
@@ -1320,10 +1324,10 @@ need_new_fragment (GstSplitMuxSink * splitmux,
   if (g_atomic_int_get (&(splitmux->split_now)) == TRUE)
     return TRUE;
 
-  if (thresh_bytes > 0 && queued_bytes >= thresh_bytes)
+  if (thresh_bytes > 0 && queued_bytes > thresh_bytes)
     return TRUE;                /* Would overrun byte limit */
 
-  if (thresh_time > 0 && queued_time >= thresh_time)
+  if (thresh_time > 0 && queued_time > thresh_time)
     return TRUE;                /* Would overrun byte limit */
 
   /* Timecode-based threshold accounts for possible rounding errors:
